#!/bin/bash
# Justin, 2025-01-01
# Copies configuration files and installs traefik
#
# User should first populate the variables for service proxying,
# as well as the paths to the TLS certificate and key. Run this script
# as root.

####################
#  USER VARIABLES  #
####################

proxy_from="example.com"
proxy_to="http://localhost:8000"
cert="${HOME}/fullchain.pem"
key="${HOME}/privkey.pem"

# Link to desired traefik release (update as needed)
url="https://github.com/traefik/traefik/releases/download/v3.2.3/traefik_v3.2.3_linux_amd64.tar.gz"


############
#  SCRIPT  #
############

# Pull traefik binary
filename="traefik-release.tar.gz"
if ! [ -f ${filename} ]; then
    curl -o ${filename} -L ${url}
fi
tar xvf ${filename} traefik

# Create traefik configuration files
cp -p ${cert} etc_traefik/certificates/fullchain.pem || exit 1
cp -p ${key} etc_traefik/certificates/privkey.pem || exit 1
sed -i "s|{{PROXY_FROM}}|${proxy_from}|" etc_traefik/providers.d/proxy.toml
sed -i "s|{{PROXY_TO}}|${proxy_to}|" etc_traefik/providers.d/proxy.toml

# Create traefik user
useradd -rMs /bin/false traefik

# Deploy binary
chown traefik:root traefik
chmod 750 traefik
mv traefik /usr/sbin/

# Deploy configuration
chown -R traefik:root etc_traefik
find etc_traefik \( -type f -exec chmod 600 {} \; \) , \( -type d -exec chmod 755 {} \; \)
rm -rf /etc/traefik
mv etc_traefik /etc/traefik

# Start service
ln -s /etc/traefik/traefik.service /etc/systemd/system/traefik.service
systemctl daemon-reload
systemctl restart traefik

# Create shortcut for certificate deployment
rm -f ${HOME}/certificates
ln -s /etc/traefik/certificates ${HOME}/certificates

# Cleanup
rm ${filename}

